@@ -16,7 +16,7 @@ limitations under the License.
 
 """
 
-import mock
+from unittest import mock
 
 from oslo_serialization import jsonutils as json
 
